@@ -1,9 +1,9 @@
-__version_info__ = ('0', '1', '6', '3')
-__date__ = '14 Feb 2021'
+__version_info__ = ('0', '1', '7', '2')
+__date__ = '7 Mar 2021'
 
 __version__ = '.'.join(__version_info__)
 __author__ = 'Tom Kwok'
 __contact__ = 'tom@tomkwok.com'
 __homepage__ = 'https://github.com/tomkwok/calplot'
 
-from .calplot import *
+from .calplot import yearplot, calplot
